@@ -37,6 +37,9 @@ import ocrolib
 import cv2
 from PIL import Image
 
+import click
+from ocrd.decorators import ocrd_cli_options, ocrd_cli_wrap_processor
+
 
 from ..constants import OCRD_TOOL
 from ocrd import Processor
@@ -451,18 +454,17 @@ class OcrdAnybaseocrCropper(Processor):
                                                           value=self.parameter[name])
                                                 for name in self.parameter.keys()])]))
             page = pcgts.get_Page()
-            page_image, page_xywh, page_image_info = self.workspace.image_from_page(page, page_id, feature_filter='cropped',feature_selector='binarized') # should also be deskewed
-
-            #page_image, page_xywh, page_image_info = self.workspace.image_from_page(
-            #    page, page_id, feature_filter='cropped')
+            page_image, page_coords, page_image_info = self.workspace.image_from_page(
+                page, page_id,
+                feature_filter='cropped',
+                feature_selector='binarized') # should also be deskewed
 
             if oplevel == "page":
                 self._process_segment(
-                    page_image, page, page_xywh, page_id, input_file, n)
+                    page_image, page, page_coords, page_id, input_file, n)
             else:
-                LOG.warning(
+                raise Exception(
                     'Operation level %s, but should be "page".', oplevel)
-                break
             file_id = input_file.ID.replace(
                 self.input_file_grp, page_grp)
 
@@ -477,16 +479,10 @@ class OcrdAnybaseocrCropper(Processor):
                 mimetype=MIMETYPE_PAGE,
                 local_filename=os.path.join(page_grp,
                                             file_id + '.xml'),
-                content=to_xml(pcgts).encode('utf-8'),
-                force=self.parameter['force']
+                content=to_xml(pcgts).encode('utf-8')
             )
 
     def _process_segment(self, page_image, page, page_xywh, page_id, input_file, n):
-        # Get image orientation
-        # orientation = page.get_orientation() # This function is not working
-        #         rotated_image = self.rotate_image(orientation, page_image)
-        #         img_array = ocrolib.pil2array(rotated_image)
-
         img_array = ocrolib.pil2array(page_image)
 
         # Check if image is RGB or not #FIXME: check not needed anymore?
@@ -541,7 +537,11 @@ class OcrdAnybaseocrCropper(Processor):
         file_path = self.workspace.save_image_file(page_image,
                                                    file_id,
                                                    page_id=page_id,
-                                                   file_grp=self.image_grp,
-                                                   force=self.parameter['force'])
+                                                   file_grp=self.image_grp)
         page.add_AlternativeImage(AlternativeImageType(
-            filename=file_path, comments=page_xywh['features']))
\ No newline at end of file
+            filename=file_path, comments=page_xywh['features']))
+
+@click.command()
+@ocrd_cli_options
+def cli(*args, **kwargs):
+    return ocrd_cli_wrap_processor(OcrdAnybaseocrCropper, *args, **kwargs)
