@@ -3,13 +3,12 @@ import pickle
 import numpy as np 
 import warnings
 warnings.filterwarnings('ignore',category=FutureWarning) 
-import tensorflow as tf
-import tensorflow.keras as keras
-from keras.models import load_model
-from keras.preprocessing.image import ImageDataGenerator
 from collections import defaultdict
 from ..constants import OCRD_TOOL
 
+import click
+from ocrd.decorators import ocrd_cli_options, ocrd_cli_wrap_processor
+
 from ocrd import Processor
 from ocrd_modelfactory import page_from_file
 from ocrd_models.ocrd_page import (
@@ -42,6 +41,10 @@ from ocrd_models.constants import (
     METS_XML_EMPTY,
 )
 
+from ..tensorflow_importer import tf, keras
+from keras.models import load_model
+from keras.preprocessing.image import ImageDataGenerator
+
 TAG_METS_STRUCTLINK = '{%s}structLink' % NS['mets']
 TAG_METS_SMLINK = '{%s}smLink' % NS['mets']
 
@@ -207,7 +210,7 @@ class OcrdAnybaseocrLayoutAnalyser(Processor):
     def process(self):
         if not tf.test.is_gpu_available():
             LOG.error("Your system has no CUDA installed. No GPU detected.")
-            sys.exit(1)
+            # sys.exit(1)
         model_path = Path(self.parameter['model_path'])
         class_mapper_path = Path(self.parameter['class_mapping_path'])
         if not Path(model_path).is_file():
@@ -257,3 +260,8 @@ class OcrdAnybaseocrLayoutAnalyser(Processor):
             self.workspace.mets.set_physical_page_for_file("PHYS_000" + str(n) , input_file)
             self.create_logmap_smlink(pcgts)
             self.write_to_mets(results, "PHYS_000" + str(n))
+
+@click.command()
+@ocrd_cli_options
+def cli(*args, **kwargs):
+    return ocrd_cli_wrap_processor(OcrdAnybaseocrLayoutAnalyser, *args, **kwargs)
