@@ -31,6 +31,8 @@ from ocrd_utils import (
     coordinates_for_segment,
     points_from_polygon,
     )
+import click
+from ocrd.decorators import ocrd_cli_options, ocrd_cli_wrap_processor
 
 from keras.models import load_model
 #from keras_segmentation.models.unet import resnet50_unet
@@ -125,7 +127,6 @@ class OcrdAnybaseocrTiseg(Processor):
                 local_filename=os.path.join(self.output_file_grp,
                                         file_id + '.xml'),
                 content=to_xml(pcgts).encode('utf-8'),
-                force=self.parameter['force']
             )
                     
     def _process_segment(self,page_image, page, page_xywh, page_id, input_file, n, model):
@@ -200,7 +201,6 @@ class OcrdAnybaseocrTiseg(Processor):
                                    file_id+"_img",
                                    page_id=page_id,
                                    file_grp=self.image_grp,
-                                   force=self.parameter['force']
             )     
         page.add_AlternativeImage(AlternativeImageType(filename=file_path, comments=page_xywh['features']+',non_text'))
         
@@ -212,7 +212,6 @@ class OcrdAnybaseocrTiseg(Processor):
                                    file_id+"_txt",
                                    page_id=page_id,
                                    file_grp=self.image_grp,
-                                   force=self.parameter['force']
             )     
         page.add_AlternativeImage(AlternativeImageType(filename=file_path, comments=page_xywh['features'])) 
     
@@ -336,3 +335,8 @@ class OcrdAnybaseocrTiseg(Processor):
         triangles = list(polygonize(m))
         return cascaded_union(triangles), edge_points
 
+
+@click.command()
+@ocrd_cli_options
+def cli(*args, **kwargs):
+    return ocrd_cli_wrap_processor(OcrdAnybaseocrTiseg, *args, **kwargs)
